ChatMessageComposerComposeContextEditing class

Режим редактирования существующего сообщения.

Inheritance

Constructors

ChatMessageComposerComposeContextEditing({required String messageId, required Document originalDocument, List<XFile> originalFiles = const []})
const
ChatMessageComposerComposeContextEditing.fromMessage(String messageId, ChatMessageComposerMessageData message)
Создаёт контекст редактирования по данным сообщения (клонирует document и files).
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageId String
final
originalDocument Document
final
originalFiles List<XFile>
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited